package Alien::GMP;

use strict;
use warnings;

use parent 'Alien::Base';

our $VERSION = '1.04'; # VERSION
# ABSTRACT: Alien package for the GNU Multiple Precision library.

sub Inline {
	return unless $_[-1] eq 'C'; # Inline's error message is good
	my $self = __PACKAGE__->new;
	+{
		LIBS => $self->libs,
		INC => $self->cflags,
		# NOTE: it may be necessary to also include
		# <stdio.h>, <stdarg.h>, or <obstack.h> before gmp.h for
		# certain functionality
		#AUTO_INCLUDE => '#include "gmp.h"',
	};
}

1;
1;
=encoding utf8

=head1 NAME

Alien::GMP - Alien package for the GNU Multiple Precision library.

=head1 Inline support

This module supports L<Inline's with functionality|Inline/"Playing 'with' Others">.

=head1 SEE ALSO

L<GMP|https://gmplib.org/>

=head1 AUTHOR

Richard Simões C<< <rsimoes AT cpan DOT org> >>

=head1 COPYRIGHT & LICENSE

Copyright © 2012 Richard Simões. This module is released under the terms of the
L<GNU Lesser General Public License|http://gnu.org/licenses/lgpl.html> ("LGPL")
v. 3.0 and may be modified and/or redistributed under the same or any compatible
license. The GNU Multiple Precision library itself is copyrighted by the
L<Free Software Foundation|http://www.fsf.org/> and is also distributed under
terms of the LGPL v. 3.0.
